@@ -60,6 +60,8 @@ struct _PersonalPhotoFramePrivate
 	gboolean slideshowRandom;
 	gboolean showSlideshowControls;
 	gboolean isPressed;
+	gboolean leftArrowPressed;
+	gboolean rightArrowPressed;
 	
 	GtkWidget *singleModeBox;
 	GtkWidget *slideshowModeBox;
@@ -210,7 +212,26 @@ void personal_photo_frame_write_settings (PersonalPhotoFrame *self)
 void personal_photo_frame_button_press (GtkWidget *widget, GdkEventButton *event, PersonalPhotoFrame *self)
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
-	self->priv->isPressed = TRUE;
+	gboolean openImage = TRUE;
+	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
+		gdouble x_coord, y_coord;
+	
+		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
+			if (y_coord > 310.0 - 48.0) {
+				if (x_coord > 310.0 - 48.0) {
+					openImage = FALSE;
+					self->priv->rightArrowPressed = TRUE;
+				} else if (x_coord < 5.0 + 48.0) {
+					openImage = FALSE;
+					self->priv->leftArrowPressed = TRUE;
+				}
+			}
+		}
+	}
+	if (openImage) {
+		self->priv->isPressed = TRUE;
+	}
+
 	gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
@@ -218,6 +239,9 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	self->priv->isPressed = FALSE;
+	self->priv->leftArrowPressed = FALSE;
+	self->priv->rightArrowPressed = FALSE;
+	gboolean openImage = TRUE;
 	
 	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
 		gdouble x_coord, y_coord;
@@ -225,35 +249,22 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
 			if (y_coord > 310.0 - 48.0) {
 				if (x_coord > 310.0 - 48.0) {
-					//self->priv->slideshowNum++;
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
 					personal_photo_frame_add_timers (self);
+					openImage = FALSE;
 				} else if (x_coord < 5.0 + 48.0) {
 					self->priv->slideshowNum-=2;
 					personal_photo_frame_update_content (self);
 					personal_photo_frame_remove_timers (self);
 					personal_photo_frame_add_timers (self);
-				} else {
-					DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
-					if (self->priv->singleMode) {
-						hildon_mime_open_file (conn, self->priv->singleFilename);
-					} else {
-						hildon_mime_open_file (conn, self->priv->slideshowFilename);
-					}
-					dbus_connection_unref(conn);
+					openImage = FALSE;
 				}
-			} else {
-				DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
-				if (self->priv->singleMode) {
-					hildon_mime_open_file (conn, self->priv->singleFilename);
-				} else {
-					hildon_mime_open_file (conn, self->priv->slideshowFilename);
-				}
-				dbus_connection_unref(conn);
 			}
 		}
-	} else {
+	}
+
+	if (openImage) {
 		DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
 		if (self->priv->singleMode) {
 			hildon_mime_open_file (conn, self->priv->singleFilename);
@@ -270,6 +281,8 @@ void personal_photo_frame_leave_event (GtkWidget *widget, GdkEventCrossing *even
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	self->priv->isPressed = FALSE;
+	self->priv->leftArrowPressed = FALSE;
+	self->priv->rightArrowPressed = FALSE;
 	gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
@@ -590,7 +603,9 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	
 	gint pixbufWidth=gdk_pixbuf_get_width(self->priv->image);
 	gint pixbufHeight=gdk_pixbuf_get_height(self->priv->image);
-	gdk_cairo_set_source_pixbuf (cr, self->priv->image, 5 + ((305-pixbufWidth)/2), 5 + ((305-pixbufHeight)/2));
+	gint leftPos = 5 + ((305 - pixbufWidth)/2);
+	gint topPos = 5 + ((305 - pixbufHeight)/2);
+	gdk_cairo_set_source_pixbuf (cr, self->priv->image, leftPos, topPos);
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 	if (!self->priv->isPressed) {
 		cairo_paint (cr);
@@ -598,6 +613,17 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 		cairo_paint_with_alpha (cr, 0.75);
 	}
 	
+	cairo_move_to (cr, leftPos -1, topPos -1);
+	cairo_line_to (cr, leftPos, topPos + 1 + pixbufHeight);
+	cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos + 1 + pixbufHeight);
+	cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos - 1);
+	cairo_line_to (cr, leftPos, topPos);
+	
+	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	cairo_set_line_width (cr, 1);
+	cairo_stroke (cr);
+	
 	cairo_destroy(cr);
 	
 	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
@@ -605,8 +631,43 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 		gdk_cairo_set_source_pixbuf (cr, self->priv->backButton, 5, 310 - 48);
 		cairo_paint_with_alpha (cr, 0.5);
 		
-		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, 310 -48, 310 - 48);
+		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, 310 - 48, 310 - 48);
 		cairo_paint_with_alpha (cr, 0.5);
+		
+		cairo_move_to (cr, 5, 310 - 48);
+		cairo_line_to (cr, 5, 310);
+		cairo_line_to (cr, 5 + 48, 310);
+		cairo_line_to (cr, 5 + 48, 310 - 48);
+		cairo_line_to (cr, 5, 310 - 48);
+		
+		if (self->priv->leftArrowPressed) {
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+			cairo_fill_preserve (cr);
+		}
+		
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
+		cairo_set_line_width (cr, 1);
+		cairo_stroke (cr);
+		
+		cairo_move_to (cr, 310 - 48, 310 - 48);
+		cairo_line_to (cr, 310 - 48, 310);
+		cairo_line_to (cr, 310, 310);
+		cairo_line_to (cr, 310, 310 - 48);
+		cairo_line_to (cr, 310 - 48, 310 - 48);
+		
+		if (self->priv->rightArrowPressed) {
+			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+			cairo_fill_preserve (cr);
+		}
+		
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
+		cairo_set_line_width (cr, 1);
+		cairo_stroke (cr);
+		
 		cairo_destroy (cr);
 	}
 	
@@ -638,6 +699,8 @@ static void personal_photo_frame_init (PersonalPhotoFrame *self)
 	self->priv = PERSONAL_PHOTO_FRAME_GET_PRIVATE (self);
 	self->priv->eventID = 0;
 	self->priv->isPressed = FALSE;
+	self->priv->leftArrowPressed = FALSE;
+	self->priv->rightArrowPressed = FALSE;
 	
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_photo_frame_settings), self);
